Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(204)

Unified Diff: scripts/slave/goma_utils.py

Issue 2245553002: Inherit appropiate environment variables in goma module for goma_utils.py (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/build.git@master
Patch Set: fix typo and etc. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | scripts/slave/recipe_modules/goma/api.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/slave/goma_utils.py
diff --git a/scripts/slave/goma_utils.py b/scripts/slave/goma_utils.py
index 1485300d2419c98feea00853759c1d97ec89cc95..a1c1253ec4c8adfbdf108a2969547cf7e00f59f2 100644
--- a/scripts/slave/goma_utils.py
+++ b/scripts/slave/goma_utils.py
@@ -41,9 +41,9 @@ def GetShortHostname():
return socket.gethostname().split('.')[0].lower()
-def GetGomaTmpDirectory():
- """Get goma's temp directory."""
- candidates = ['GOMA_TMP_DIR', 'TEST_TMPDIR', 'TMPDIR', 'TMP']
+def GetGomaLogDirectory():
+ """Get goma's log directory."""
+ candidates = ['TEST_TMPDIR', 'TMPDIR', 'TMP']
for candidate in candidates:
value = os.environ.get(candidate)
if value and os.path.isdir(value):
@@ -60,7 +60,7 @@ def GetLatestGlogInfoFile(pattern):
Returns:
the latest glog INFO filename in fullpath.
"""
- dirname = GetGomaTmpDirectory()
+ dirname = GetGomaLogDirectory()
info_pattern = os.path.join(dirname, '%s.*.INFO.*' % pattern)
candidates = glob.glob(info_pattern)
if not candidates:
« no previous file with comments | « no previous file | scripts/slave/recipe_modules/goma/api.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698